from setuptools import setup

setup(
    name='lqr',
    version='0.0.1',
    py_modules=['lqr'],
    # description='',
    author='Max M. Sun',
    author_email='maxxmsun@gmail.com',
    # url='',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
    ],
    python_requires='>=3.8',
)